==> traction-7.x-1.0.tar.gz: traction/templates/page--front.tpl.php <==
<div class="skip-content"><a href="#content">Skip to content</a></div>
	<div id="pg-nav-bg">
		<div class="wrapper container-12 clearfix">
			<div id="pg-nav" class="menu-top-menu-container" >
				<?php if ($primary_nav): print $primary_nav; endif; ?>
       </div>
     </div><!--end wrapper-->
	</div><!--end page-navigation-bg-->
	<div class="wrapper big">
		<div id="header" class="clear">
							<div class="logo grid-12">
					 <?php if ($logo): ?>
          <a href="<?php print check_url($front_page); ?>" title="<?php print t('Home'); ?>">
            <img src="<?php print $logo; ?>" alt="<?php print $site_name; ?>" />
          </a>
        <?php endif; ?>
									</div><!--end logo-->
									<div id="cat-nav" class="grid-12">
										<?php if ($secondary_nav): print $secondary_nav; endif; ?>
									</div>		</div><!--end header-->
					<div class="feature-top clear"></div>
<div id="feature" class="container-16 clearfix" >
	<div class="grid-11 omega">
		<?php print render($page ['featured']); ?>			
	</div><!--end feature-main-->
	<div class="grid-5 alpha">
		<?php print render($page ['featured_sidebar']); ?><div class="clear"></div>
			</div><!--end feature-sidebar-->
</div><!--end feature-->
<div class="feature-bottom clear"></div>			
<div id="main-top" class="container-16">
		<div class="grid-11"><h4>Recent Articles</h4></div>
		<div class="grid-5">
			<?php print render($page['subscribe']); ?>	
	</div>	
	</div>

	<div id="main" class="container-16 clear">
		<div id="content" class="grid-11 alpha omega">
			<?php print $messages; ?>
			<?php if ($tabs): ?>
            <?php print render($tabs); ?>
      <?php endif; ?>
			<?php print render($page['content']); ?>										
		</div><!--end content-->
		<div id="sidebar" class="grid-5 alpha omega">
			<?php print render($page['ads']); ?>		
			
				<?php print render($page['right_sidebar']); ?>					
		</div><!--end sidebar-->	
	</div>
	<div id="main-bottom"></div>
</div><!--end wrapper-->



<div id="footer" >
	<div class="wrapper container-12 clearfix">
		<div  class="footer-column  grid-4">
        	
			  <?php print render($page['footer_first']); ?>  
			  
			  
		</div>
		<div class="footer-column  grid-4">
     	 <?php print render($page['footer_second']); ?>
		</div>
		<div class="footer-column  grid-4">
			  <?php print render($page['footer_third']); ?>		

	
		</div>
		
	</div><!--end wrapper-->
</div><!--end footer-->
<div id="copyright" class="wrapper container-12 clearfix">
	 <div class="grid-8">
	  <?php print render($page['footer_fourth']); ?>	
	</div>
	<div class="grid-4">
	  <?php print render($page['footer_fifth']); ?>
	</div>
	<p class="credit">
		Designed by <a href="http://thethemefoundry.com/traction/" title="Traction" target="_blank">The Theme Foundry</a> . &nbsp&nbsp
				Developed by <a href="http://www.zyxware.com/" title="Zyxware" target="_blank">Zyxware</a> 	
				
	</p>
</div>

==> traction-7.x-1.2.tar.gz: traction/templates/page--front.tpl.php <==
<div class="skip-content"><a href="#content">Skip to content</a></div>
	<div id="pg-nav-bg">
		<div class="wrapper container-12 clearfix">
			<div id="pg-nav" class="menu-top-menu-container" >
				<?php if ($primary_nav): print $primary_nav; endif; ?>
       </div>
     </div><!--end wrapper-->
	</div><!--end page-navigation-bg-->
	<div class="wrapper big">
		<div id="header" class="clear">
							<div class="logo grid-12">
					 <?php if ($logo): ?>
          <a href="<?php print check_url($front_page); ?>" title="<?php print t('Home'); ?>">
            <img src="<?php print $logo; ?>" alt="<?php print $site_name; ?>" />
          </a>
        <?php endif; ?>
									</div><!--end logo-->
									<div id="cat-nav" class="grid-12">
										<?php if ($secondary_nav): print $secondary_nav; endif; ?>
									</div>		</div><!--end header-->
					<div class="feature-top clear"></div>
<div id="feature" class="container-16 clearfix" >
	<div class="grid-11 omega">
		<?php print render($page ['featured']); ?>			
	</div><!--end feature-main-->
	<div class="grid-5 alpha">
		<?php print render($page ['featured_sidebar']); ?><div class="clear"></div>
			</div><!--end feature-sidebar-->
</div><!--end feature-->
<div class="feature-bottom clear"></div>			
<div id="main-top" class="container-16">
		<div class="grid-11"><h4>Recent Articles</h4></div>
		<?php if ($page['ads'] || $page['sidebar_second']): ?>
		  <div class="grid-5">
			  <?php print render($page['subscribe']); ?>	
    	</div>	
    <?php endif; ?>
	</div>

	<div id="main" class="container-16 clear">
		<div id="content" class="grid-11 alpha omega">
			<?php print $messages; ?>
			<?php if ($tabs): ?>
            <?php print render($tabs); ?>
      <?php endif; ?>
			<?php if ($page['content']): ?>
  			<?php print render($page['content']); ?>
			<?php endif; ?>										
		</div><!--end content-->
		<?php if ($page['ads'] || $page['sidebar_second']): ?>
		  <div id="sidebar" class="grid-5 alpha omega">
		    <?php if ($page['ads']): ?>
			    <?php print render($page['ads']); ?>		
			  <?php endif; ?> 
			  <?php if ($page['sidebar_second']): ?>
  			  <?php print render($page['sidebar_second']); ?>				
  			<?php endif; ?>	
	  	</div><!--end sidebar-->	
		<?php endif; ?>	
	</div>
	<div id="main-bottom"></div>
</div><!--end wrapper-->



<div id="footer" >
	<div class="wrapper container-12 clearfix">
		<div  class="footer-column  grid-4">
        	
			  <?php print render($page['footer_first']); ?>  
			  
			  
		</div>
		<div class="footer-column  grid-4">
     	 <?php print render($page['footer_second']); ?>
		</div>
		<div class="footer-column  grid-4">
			  <?php print render($page['footer_third']); ?>		

	
		</div>
		
	</div><!--end wrapper-->
</div><!--end footer-->
<div id="copyright" class="wrapper container-12 clearfix">
	 <div class="grid-4">
	  <?php print render($page['footer_fourth']); ?>	
	</div>
	<div class="grid-3">
	  <?php print render($page['footer_fifth']); ?>
	</div>
	<div class="grid-5">
		Designed by <a href="http://thethemefoundry.com/traction/" title="Traction" target="_blank">The Theme Foundry</a> . &nbsp&nbsp
				Developed by <a href="http://www.zyxware.com/" title="Zyxware" target="_blank">Zyxware</a> 	
				
	</div>
</div>
